# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from CommandCenter.api_client import ApiClient


class DriveApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def designates_drive_as_cache_drive(self, cloud_name, id, **kwargs):  # noqa: E501
        """designates_drive_as_cache_drive  # noqa: E501

        Designates a drive as a cache drive.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.designates_drive_as_cache_drive(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.designates_drive_as_cache_drive_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
        else:
            (data) = self.designates_drive_as_cache_drive_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
            return data

    def designates_drive_as_cache_drive_with_http_info(self, cloud_name, id, **kwargs):  # noqa: E501
        """designates_drive_as_cache_drive  # noqa: E501

        Designates a drive as a cache drive.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.designates_drive_as_cache_drive_with_http_info(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method designates_drive_as_cache_drive" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `designates_drive_as_cache_drive`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `designates_drive_as_cache_drive`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/drives/{id}/designate_as_cache.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def disable_drive(self, cloud_name, id, **kwargs):  # noqa: E501
        """disable_drive  # noqa: E501

        Disables a drive. Removes the drive from the Zadara Cloud inventory. Disabled drives can not be allocated to VPSA  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.disable_drive(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.disable_drive_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
        else:
            (data) = self.disable_drive_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
            return data

    def disable_drive_with_http_info(self, cloud_name, id, **kwargs):  # noqa: E501
        """disable_drive  # noqa: E501

        Disables a drive. Removes the drive from the Zadara Cloud inventory. Disabled drives can not be allocated to VPSA  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.disable_drive_with_http_info(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method disable_drive" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `disable_drive`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `disable_drive`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/drives/{id}/disable.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def disable_drives_led(self, cloud_name, id, **kwargs):  # noqa: E501
        """disable_drives_led  # noqa: E501

        Disables a drive's LED.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.disable_drives_led(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.disable_drives_led_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
        else:
            (data) = self.disable_drives_led_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
            return data

    def disable_drives_led_with_http_info(self, cloud_name, id, **kwargs):  # noqa: E501
        """disable_drives_led  # noqa: E501

        Disables a drive's LED.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.disable_drives_led_with_http_info(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method disable_drives_led" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `disable_drives_led`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `disable_drives_led`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/drives/{id}/disable_led.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def enable_drive(self, cloud_name, id, **kwargs):  # noqa: E501
        """enable_drive  # noqa: E501

        Enables a drive. Adds the drive back to the Zadara Cloud inventory. Enabled drive can be allocated to a VPSA.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.enable_drive(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.enable_drive_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
        else:
            (data) = self.enable_drive_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
            return data

    def enable_drive_with_http_info(self, cloud_name, id, **kwargs):  # noqa: E501
        """enable_drive  # noqa: E501

        Enables a drive. Adds the drive back to the Zadara Cloud inventory. Enabled drive can be allocated to a VPSA.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.enable_drive_with_http_info(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method enable_drive" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `enable_drive`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `enable_drive`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/drives/{id}/enable.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def enable_drives_led(self, cloud_name, id, **kwargs):  # noqa: E501
        """enable_drives_led  # noqa: E501

        Enables a drive's LED.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.enable_drives_led(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.enable_drives_led_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
        else:
            (data) = self.enable_drives_led_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
            return data

    def enable_drives_led_with_http_info(self, cloud_name, id, **kwargs):  # noqa: E501
        """enable_drives_led  # noqa: E501

        Enables a drive's LED.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.enable_drives_led_with_http_info(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method enable_drives_led" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `enable_drives_led`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `enable_drives_led`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/drives/{id}/enable_led.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_drives(self, cloud_name, **kwargs):  # noqa: E501
        """get_all_drives  # noqa: E501

        Returns a list of all the drives in a Zadara Storage Cloud.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_drives(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param int page: The page number to start from.
        :param int per_page: The total number of records to return.
        :return: InlineResponse20018
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_drives_with_http_info(cloud_name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_all_drives_with_http_info(cloud_name, **kwargs)  # noqa: E501
            return data

    def get_all_drives_with_http_info(self, cloud_name, **kwargs):  # noqa: E501
        """get_all_drives  # noqa: E501

        Returns a list of all the drives in a Zadara Storage Cloud.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_drives_with_http_info(cloud_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param int page: The page number to start from.
        :param int per_page: The total number of records to return.
        :return: InlineResponse20018
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'page', 'per_page']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_drives" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `get_all_drives`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501

        query_params = []
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'per_page' in params:
            query_params.append(('per_page', params['per_page']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/drives.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20018',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_drive(self, cloud_name, id, **kwargs):  # noqa: E501
        """get_drive  # noqa: E501

        Returns detailed information about a single drive.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_drive(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse20019
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_drive_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_drive_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
            return data

    def get_drive_with_http_info(self, cloud_name, id, **kwargs):  # noqa: E501
        """get_drive  # noqa: E501

        Returns detailed information about a single drive.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_drive_with_http_info(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse20019
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_drive" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `get_drive`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_drive`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/drives/{id}.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20019',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_drive_smart(self, cloud_name, id, **kwargs):  # noqa: E501
        """get_drive_smart  # noqa: E501

        Returns a drive's SMART attributes.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_drive_smart(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse20022
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_drive_smart_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_drive_smart_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
            return data

    def get_drive_smart_with_http_info(self, cloud_name, id, **kwargs):  # noqa: E501
        """get_drive_smart  # noqa: E501

        Returns a drive's SMART attributes.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_drive_smart_with_http_info(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse20022
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_drive_smart" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `get_drive_smart`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_drive_smart`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/drives/{id}/smart_attributes.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20022',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_drive_smart_test_results(self, cloud_name, id, **kwargs):  # noqa: E501
        """get_drive_smart_test_results  # noqa: E501

        Returns a drive's SMART test results.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_drive_smart_test_results(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse20023
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_drive_smart_test_results_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_drive_smart_test_results_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
            return data

    def get_drive_smart_test_results_with_http_info(self, cloud_name, id, **kwargs):  # noqa: E501
        """get_drive_smart_test_results  # noqa: E501

        Returns a drive's SMART test results.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_drive_smart_test_results_with_http_info(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse20023
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_drive_smart_test_results" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `get_drive_smart_test_results`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_drive_smart_test_results`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/drives/{id}/smart_test_results.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20023',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_drives_details_end_location(self, cloud_name, id, **kwargs):  # noqa: E501
        """get_drives_details_end_location  # noqa: E501

        Show a drive's details including location information.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_drives_details_end_location(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse20021
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_drives_details_end_location_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_drives_details_end_location_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
            return data

    def get_drives_details_end_location_with_http_info(self, cloud_name, id, **kwargs):  # noqa: E501
        """get_drives_details_end_location  # noqa: E501

        Show a drive's details including location information.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_drives_details_end_location_with_http_info(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse20021
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_drives_details_end_location" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `get_drives_details_end_location`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_drives_details_end_location`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/drives/{id}/details.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20021',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def license_an_availiable_drive(self, cloud_name, id, **kwargs):  # noqa: E501
        """license_an_availiable_drive  # noqa: E501

        License an available (non_allocated) drive. This API allow manual selection of the licensed drives in a Storage Node  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.license_an_availiable_drive(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.license_an_availiable_drive_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
        else:
            (data) = self.license_an_availiable_drive_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
            return data

    def license_an_availiable_drive_with_http_info(self, cloud_name, id, **kwargs):  # noqa: E501
        """license_an_availiable_drive  # noqa: E501

        License an available (non_allocated) drive. This API allow manual selection of the licensed drives in a Storage Node  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.license_an_availiable_drive_with_http_info(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method license_an_availiable_drive" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `license_an_availiable_drive`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `license_an_availiable_drive`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/drives/{id}/license.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_drive_comments(self, cloud_name, id, **kwargs):  # noqa: E501
        """list_drive_comments  # noqa: E501

        Returns the list of the drive comments.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_drive_comments(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse20020
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_drive_comments_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_drive_comments_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
            return data

    def list_drive_comments_with_http_info(self, cloud_name, id, **kwargs):  # noqa: E501
        """list_drive_comments  # noqa: E501

        Returns the list of the drive comments.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_drive_comments_with_http_info(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse20020
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_drive_comments" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `list_drive_comments`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `list_drive_comments`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/drives/{id}/comments.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20020',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_drive(self, cloud_name, id, **kwargs):  # noqa: E501
        """remove_drive  # noqa: E501

        Removes a drive. Removed drives can not be restored.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_drive(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_drive_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_drive_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
            return data

    def remove_drive_with_http_info(self, cloud_name, id, **kwargs):  # noqa: E501
        """remove_drive  # noqa: E501

        Removes a drive. Removed drives can not be restored.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_drive_with_http_info(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_drive" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `remove_drive`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `remove_drive`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/drives/{id}/remove.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def replace_allocated_drive(self, cloud_name, id, **kwargs):  # noqa: E501
        """replace_allocated_drive  # noqa: E501

        Replaces a drive which is allocated to a VPSA. This command will allocate a new drive of the same drive type for the VPSA, replace the drive in the RaidGroup and free the replaced drive back to the Zadara Cloud repository.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.replace_allocated_drive(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :param Faulty faulty:
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.replace_allocated_drive_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
        else:
            (data) = self.replace_allocated_drive_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
            return data

    def replace_allocated_drive_with_http_info(self, cloud_name, id, **kwargs):  # noqa: E501
        """replace_allocated_drive  # noqa: E501

        Replaces a drive which is allocated to a VPSA. This command will allocate a new drive of the same drive type for the VPSA, replace the drive in the RaidGroup and free the replaced drive back to the Zadara Cloud repository.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.replace_allocated_drive_with_http_info(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :param Faulty faulty:
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'id', 'faulty']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method replace_allocated_drive" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `replace_allocated_drive`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `replace_allocated_drive`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'faulty' in params:
            body_params = params['faulty']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/drives/{id}/replace.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def run_drive_smart_test(self, cloud_name, id, **kwargs):  # noqa: E501
        """run_drive_smart_test  # noqa: E501

        Run a drive's SMART test.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.run_drive_smart_test(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse20024
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.run_drive_smart_test_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
        else:
            (data) = self.run_drive_smart_test_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
            return data

    def run_drive_smart_test_with_http_info(self, cloud_name, id, **kwargs):  # noqa: E501
        """run_drive_smart_test  # noqa: E501

        Run a drive's SMART test.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.run_drive_smart_test_with_http_info(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse20024
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method run_drive_smart_test" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `run_drive_smart_test`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `run_drive_smart_test`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/drives/{id}/run_smart_test.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20024',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def show_drives_metered_performane_information(self, cloud_name, id, **kwargs):  # noqa: E501
        """show_drives_metered_performane_information  # noqa: E501

        Show metered performance information for a drive.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.show_drives_metered_performane_information(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse20025
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.show_drives_metered_performane_information_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
        else:
            (data) = self.show_drives_metered_performane_information_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
            return data

    def show_drives_metered_performane_information_with_http_info(self, cloud_name, id, **kwargs):  # noqa: E501
        """show_drives_metered_performane_information  # noqa: E501

        Show metered performance information for a drive.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.show_drives_metered_performane_information_with_http_info(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse20025
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method show_drives_metered_performane_information" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `show_drives_metered_performane_information`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `show_drives_metered_performane_information`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/drives/{id}/performance.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20025',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def undesignate_drive_as_cache_drive(self, cloud_name, id, **kwargs):  # noqa: E501
        """undesignate_drive_as_cache_drive  # noqa: E501

        Undesignate a drive as cache drive.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.undesignate_drive_as_cache_drive(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.undesignate_drive_as_cache_drive_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
        else:
            (data) = self.undesignate_drive_as_cache_drive_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
            return data

    def undesignate_drive_as_cache_drive_with_http_info(self, cloud_name, id, **kwargs):  # noqa: E501
        """undesignate_drive_as_cache_drive  # noqa: E501

        Undesignate a drive as cache drive.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.undesignate_drive_as_cache_drive_with_http_info(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method undesignate_drive_as_cache_drive" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `undesignate_drive_as_cache_drive`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `undesignate_drive_as_cache_drive`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/drives/{id}/undesignate_as_cache.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def unlicense_an_availiable_drive(self, cloud_name, id, **kwargs):  # noqa: E501
        """unlicense_an_availiable_drive  # noqa: E501

        Unlicense an available (non_allocated) drive. This API allow manual selection of the licensed drives in a Storage Node  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.unlicense_an_availiable_drive(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.unlicense_an_availiable_drive_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
        else:
            (data) = self.unlicense_an_availiable_drive_with_http_info(cloud_name, id, **kwargs)  # noqa: E501
            return data

    def unlicense_an_availiable_drive_with_http_info(self, cloud_name, id, **kwargs):  # noqa: E501
        """unlicense_an_availiable_drive  # noqa: E501

        Unlicense an available (non_allocated) drive. This API allow manual selection of the licensed drives in a Storage Node  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.unlicense_an_availiable_drive_with_http_info(cloud_name, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str cloud_name: (required)
        :param str id: (required)
        :return: InlineResponse2004
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['cloud_name', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method unlicense_an_availiable_drive" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'cloud_name' is set
        if self.api_client.client_side_validation and ('cloud_name' not in params or
                                                       params['cloud_name'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `cloud_name` when calling `unlicense_an_availiable_drive`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `unlicense_an_availiable_drive`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cloud_name' in params:
            path_params['cloud_name'] = params['cloud_name']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/clouds/{cloud_name}/drives/{id}/unlicense.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2004',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Zadara VPSA Object Storage REST API

    # Overview  This document outlines the methods available for administrating your VPSA&#174; Object Storage. The API supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or through the X-Access-Key header. Alternately, you can use the username and password parameters for authentication, but we do not recommend this method for anything other than possibly retrieving an API key.  By default , all operations are allowed only to VPSA Object Storage admin. Some actions are allowed by an account admin and they will be marked on the action's header  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some time to complete. When using the API, this can cause some actions, such as adding drives to storage policy, to be undesirably asynchronous. You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Metering API  Metering information can be retrieved using the VPSA Object Storage API for the following components:  - Accounts - Users - Drives - Virtual Controllers - Load Balancer Groups - Storage Policies  Metering information returned by the API is subject to the following constraints:  - 10 seconds interval - 1 hour range - 1 minute interval - 1 day range - 1 hour interval - 30 days range  Values outside the accepted range will be returned as 0.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import Zios
from Zios.api.settings_api import SettingsApi  # noqa: E501
from Zios.rest import ApiException


class TestSettingsApi(unittest.TestCase):
    """SettingsApi unit test stubs"""

    def setUp(self):
        self.api = Zios.api.settings_api.SettingsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_activate_encryption(self):
        """Test case for activate_encryption

        """
        pass

    def test_allow_tenant_name_in_object_stroage_url(self):
        """Test case for allow_tenant_name_in_object_stroage_url

        """
        pass

    def test_change_mtu_for_network_interface(self):
        """Test case for change_mtu_for_network_interface

        """
        pass

    def test_change_region(self):
        """Test case for change_region

        """
        pass

    def test_define_custom_dns_servers(self):
        """Test case for define_custom_dns_servers

        """
        pass

    def test_disable_encryption(self):
        """Test case for disable_encryption

        """
        pass

    def test_get_network(self):
        """Test case for get_network

        """
        pass

    def test_get_settings_config(self):
        """Test case for get_settings_config

        """
        pass

    def test_get_ssl_cert_info(self):
        """Test case for get_ssl_cert_info

        """
        pass

    def test_restore_encryption(self):
        """Test case for restore_encryption

        """
        pass

    def test_set_api_errors_alerts(self):
        """Test case for set_api_errors_alerts

        """
        pass

    def test_set_api_hostname(self):
        """Test case for set_api_hostname

        """
        pass

    def test_set_api_ip(self):
        """Test case for set_api_ip

        """
        pass

    def test_set_billing_currency(self):
        """Test case for set_billing_currency

        """
        pass

    def test_set_containers_virtual_hosted_style_support(self):
        """Test case for set_containers_virtual_hosted_style_support

        """
        pass

    def test_set_data_transfer_pricing(self):
        """Test case for set_data_transfer_pricing

        """
        pass

    def test_set_encryption(self):
        """Test case for set_encryption

        """
        pass

    def test_set_global_rate_limit(self):
        """Test case for set_global_rate_limit

        """
        pass

    def test_set_gradual_policy_expansion_percentage(self):
        """Test case for set_gradual_policy_expansion_percentage

        """
        pass

    def test_set_lb_mode(self):
        """Test case for set_lb_mode

        """
        pass

    def test_set_public_ip_hostname(self):
        """Test case for set_public_ip_hostname

        """
        pass

    def test_ssl_termination(self):
        """Test case for ssl_termination

        """
        pass

    def test_token_expiration(self):
        """Test case for token_expiration

        """
        pass

    def test_upload_ssl_pem(self):
        """Test case for upload_ssl_pem

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class CreateComment(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'content': 'str',
        'type': 'str',
        'id': 'int',
        'severity': 'str',
        'pin_to_dashboard': 'bool'
    }

    attribute_map = {
        'content': 'content',
        'type': 'type',
        'id': 'id',
        'severity': 'severity',
        'pin_to_dashboard': 'pin_to_dashboard'
    }

    def __init__(self, content=None, type=None, id=None, severity=None, pin_to_dashboard=None, _configuration=None):  # noqa: E501
        """CreateComment - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._content = None
        self._type = None
        self._id = None
        self._severity = None
        self._pin_to_dashboard = None
        self.discriminator = None

        if content is not None:
            self.content = content
        if type is not None:
            self.type = type
        if id is not None:
            self.id = id
        if severity is not None:
            self.severity = severity
        if pin_to_dashboard is not None:
            self.pin_to_dashboard = pin_to_dashboard

    @property
    def content(self):
        """Gets the content of this CreateComment.  # noqa: E501


        :return: The content of this CreateComment.  # noqa: E501
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this CreateComment.


        :param content: The content of this CreateComment.  # noqa: E501
        :type: str
        """

        self._content = content

    @property
    def type(self):
        """Gets the type of this CreateComment.  # noqa: E501


        :return: The type of this CreateComment.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CreateComment.


        :param type: The type of this CreateComment.  # noqa: E501
        :type: str
        """
        allowed_values = ["Vpsa", "Zios", "Drive", "DriveType", "Node", "Cloud"]  # noqa: E501
        if (self._configuration.client_side_validation and
                type not in allowed_values):
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def id(self):
        """Gets the id of this CreateComment.  # noqa: E501

        id of the entity this comment will be attached to  # noqa: E501

        :return: The id of this CreateComment.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CreateComment.

        id of the entity this comment will be attached to  # noqa: E501

        :param id: The id of this CreateComment.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def severity(self):
        """Gets the severity of this CreateComment.  # noqa: E501


        :return: The severity of this CreateComment.  # noqa: E501
        :rtype: str
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """Sets the severity of this CreateComment.


        :param severity: The severity of this CreateComment.  # noqa: E501
        :type: str
        """
        allowed_values = ["low", "medium", "high", "critical"]  # noqa: E501
        if (self._configuration.client_side_validation and
                severity not in allowed_values):
            raise ValueError(
                "Invalid value for `severity` ({0}), must be one of {1}"  # noqa: E501
                .format(severity, allowed_values)
            )

        self._severity = severity

    @property
    def pin_to_dashboard(self):
        """Gets the pin_to_dashboard of this CreateComment.  # noqa: E501

        Pin comment to dashboard. Cloud type comment is automatically pinned to dashboard.  # noqa: E501

        :return: The pin_to_dashboard of this CreateComment.  # noqa: E501
        :rtype: bool
        """
        return self._pin_to_dashboard

    @pin_to_dashboard.setter
    def pin_to_dashboard(self, pin_to_dashboard):
        """Sets the pin_to_dashboard of this CreateComment.

        Pin comment to dashboard. Cloud type comment is automatically pinned to dashboard.  # noqa: E501

        :param pin_to_dashboard: The pin_to_dashboard of this CreateComment.  # noqa: E501
        :type: bool
        """

        self._pin_to_dashboard = pin_to_dashboard

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateComment, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateComment):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateComment):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Object Storage REST API

    # Overview  This document outlines the methods available for administrating your VPSA&#174; Object Storage. The API supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or through the X-Access-Key header. Alternately, you can use the username and password parameters for authentication, but we do not recommend this method for anything other than possibly retrieving an API key.  By default , all operations are allowed only to VPSA Object Storage admin. Some actions are allowed by an account admin and they will be marked on the action's header  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some time to complete. When using the API, this can cause some actions, such as adding drives to storage policy, to be undesirably asynchronous. You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Metering API  Metering information can be retrieved using the VPSA Object Storage API for the following components:  - Accounts - Users - Drives - Virtual Controllers - Load Balancer Groups - Storage Policies  Metering information returned by the API is subject to the following constraints:  - 10 seconds interval - 1 hour range - 1 minute interval - 1 day range - 1 hour interval - 30 days range  Values outside the accepted range will be returned as 0.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Zios.configuration import Configuration


class InlineResponse20027Response(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'message': 'str',
        'name': 'str',
        'uuid': 'str',
        'display_name': 'str',
        'url': 'str',
        'auth_service_url': 'str',
        'version': 'str',
        'language': 'str',
        'multi_zone': 'str',
        'floating_fe_ip': 'str',
        'floating_fe_ipv6': 'str',
        'floating_be_ip': 'str',
        'publicip': 'str',
        'auto_scale': 'str',
        'billing_unit': 'str',
        'upload_rate_per_gb': 'str',
        'download_rate_per_gb': 'str',
        'api_ip': 'str',
        'api_hostname': 'str',
        'zswift_ratelimit_enabled': 'str',
        'zswift_ratelimit': 'str',
        'vhs_state': 'str',
        'admin_access_enabled': 'str',
        'allow_tenant_name_in_url': 'str',
        'token_expiry': 'str',
        'policy_action': 'str',
        'zios_upgrade': 'str',
        'ssl_termination': 'str',
        'created_at': 'str',
        'modified_at': 'str',
        'expire_password': 'str',
        'expire_password_after': 'str',
        'password_history': 'str'
    }

    attribute_map = {
        'message': 'message',
        'name': 'name',
        'uuid': 'uuid',
        'display_name': 'display_name',
        'url': 'url',
        'auth_service_url': 'auth_service_url',
        'version': 'version',
        'language': 'language',
        'multi_zone': 'multi-zone',
        'floating_fe_ip': 'floating_fe_ip',
        'floating_fe_ipv6': 'floating_fe_ipv6',
        'floating_be_ip': 'floating_be_ip',
        'publicip': 'publicip',
        'auto_scale': 'auto_scale',
        'billing_unit': 'billing_unit',
        'upload_rate_per_gb': 'upload_rate_per_gb',
        'download_rate_per_gb': 'download_rate_per_gb',
        'api_ip': 'api_ip',
        'api_hostname': 'api_hostname',
        'zswift_ratelimit_enabled': 'zswift_ratelimit_enabled',
        'zswift_ratelimit': 'zswift_ratelimit',
        'vhs_state': 'vhs_state',
        'admin_access_enabled': 'admin_access_enabled',
        'allow_tenant_name_in_url': 'allow_tenant_name_in_url',
        'token_expiry': 'token_expiry',
        'policy_action': 'policy_action',
        'zios_upgrade': 'zios_upgrade',
        'ssl_termination': 'ssl_termination',
        'created_at': 'created_at',
        'modified_at': 'modified_at',
        'expire_password': 'expire_password',
        'expire_password_after': 'expire_password_after',
        'password_history': 'password_history'
    }

    def __init__(self, message=None, name=None, uuid=None, display_name=None, url=None, auth_service_url=None, version=None, language=None, multi_zone=None, floating_fe_ip=None, floating_fe_ipv6=None, floating_be_ip=None, publicip=None, auto_scale=None, billing_unit=None, upload_rate_per_gb=None, download_rate_per_gb=None, api_ip=None, api_hostname=None, zswift_ratelimit_enabled=None, zswift_ratelimit=None, vhs_state=None, admin_access_enabled=None, allow_tenant_name_in_url=None, token_expiry=None, policy_action=None, zios_upgrade=None, ssl_termination=None, created_at=None, modified_at=None, expire_password=None, expire_password_after=None, password_history=None, _configuration=None):  # noqa: E501
        """InlineResponse20027Response - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._message = None
        self._name = None
        self._uuid = None
        self._display_name = None
        self._url = None
        self._auth_service_url = None
        self._version = None
        self._language = None
        self._multi_zone = None
        self._floating_fe_ip = None
        self._floating_fe_ipv6 = None
        self._floating_be_ip = None
        self._publicip = None
        self._auto_scale = None
        self._billing_unit = None
        self._upload_rate_per_gb = None
        self._download_rate_per_gb = None
        self._api_ip = None
        self._api_hostname = None
        self._zswift_ratelimit_enabled = None
        self._zswift_ratelimit = None
        self._vhs_state = None
        self._admin_access_enabled = None
        self._allow_tenant_name_in_url = None
        self._token_expiry = None
        self._policy_action = None
        self._zios_upgrade = None
        self._ssl_termination = None
        self._created_at = None
        self._modified_at = None
        self._expire_password = None
        self._expire_password_after = None
        self._password_history = None
        self.discriminator = None

        if message is not None:
            self.message = message
        if name is not None:
            self.name = name
        if uuid is not None:
            self.uuid = uuid
        if display_name is not None:
            self.display_name = display_name
        if url is not None:
            self.url = url
        if auth_service_url is not None:
            self.auth_service_url = auth_service_url
        if version is not None:
            self.version = version
        if language is not None:
            self.language = language
        if multi_zone is not None:
            self.multi_zone = multi_zone
        if floating_fe_ip is not None:
            self.floating_fe_ip = floating_fe_ip
        if floating_fe_ipv6 is not None:
            self.floating_fe_ipv6 = floating_fe_ipv6
        if floating_be_ip is not None:
            self.floating_be_ip = floating_be_ip
        if publicip is not None:
            self.publicip = publicip
        if auto_scale is not None:
            self.auto_scale = auto_scale
        if billing_unit is not None:
            self.billing_unit = billing_unit
        if upload_rate_per_gb is not None:
            self.upload_rate_per_gb = upload_rate_per_gb
        if download_rate_per_gb is not None:
            self.download_rate_per_gb = download_rate_per_gb
        if api_ip is not None:
            self.api_ip = api_ip
        if api_hostname is not None:
            self.api_hostname = api_hostname
        if zswift_ratelimit_enabled is not None:
            self.zswift_ratelimit_enabled = zswift_ratelimit_enabled
        if zswift_ratelimit is not None:
            self.zswift_ratelimit = zswift_ratelimit
        if vhs_state is not None:
            self.vhs_state = vhs_state
        if admin_access_enabled is not None:
            self.admin_access_enabled = admin_access_enabled
        if allow_tenant_name_in_url is not None:
            self.allow_tenant_name_in_url = allow_tenant_name_in_url
        if token_expiry is not None:
            self.token_expiry = token_expiry
        if policy_action is not None:
            self.policy_action = policy_action
        if zios_upgrade is not None:
            self.zios_upgrade = zios_upgrade
        if ssl_termination is not None:
            self.ssl_termination = ssl_termination
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at
        if expire_password is not None:
            self.expire_password = expire_password
        if expire_password_after is not None:
            self.expire_password_after = expire_password_after
        if password_history is not None:
            self.password_history = password_history

    @property
    def message(self):
        """Gets the message of this InlineResponse20027Response.  # noqa: E501


        :return: The message of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this InlineResponse20027Response.


        :param message: The message of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def name(self):
        """Gets the name of this InlineResponse20027Response.  # noqa: E501


        :return: The name of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse20027Response.


        :param name: The name of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def uuid(self):
        """Gets the uuid of this InlineResponse20027Response.  # noqa: E501


        :return: The uuid of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this InlineResponse20027Response.


        :param uuid: The uuid of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._uuid = uuid

    @property
    def display_name(self):
        """Gets the display_name of this InlineResponse20027Response.  # noqa: E501


        :return: The display_name of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this InlineResponse20027Response.


        :param display_name: The display_name of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def url(self):
        """Gets the url of this InlineResponse20027Response.  # noqa: E501


        :return: The url of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this InlineResponse20027Response.


        :param url: The url of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def auth_service_url(self):
        """Gets the auth_service_url of this InlineResponse20027Response.  # noqa: E501


        :return: The auth_service_url of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._auth_service_url

    @auth_service_url.setter
    def auth_service_url(self, auth_service_url):
        """Sets the auth_service_url of this InlineResponse20027Response.


        :param auth_service_url: The auth_service_url of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._auth_service_url = auth_service_url

    @property
    def version(self):
        """Gets the version of this InlineResponse20027Response.  # noqa: E501


        :return: The version of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this InlineResponse20027Response.


        :param version: The version of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def language(self):
        """Gets the language of this InlineResponse20027Response.  # noqa: E501


        :return: The language of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this InlineResponse20027Response.


        :param language: The language of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._language = language

    @property
    def multi_zone(self):
        """Gets the multi_zone of this InlineResponse20027Response.  # noqa: E501


        :return: The multi_zone of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._multi_zone

    @multi_zone.setter
    def multi_zone(self, multi_zone):
        """Sets the multi_zone of this InlineResponse20027Response.


        :param multi_zone: The multi_zone of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._multi_zone = multi_zone

    @property
    def floating_fe_ip(self):
        """Gets the floating_fe_ip of this InlineResponse20027Response.  # noqa: E501


        :return: The floating_fe_ip of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._floating_fe_ip

    @floating_fe_ip.setter
    def floating_fe_ip(self, floating_fe_ip):
        """Sets the floating_fe_ip of this InlineResponse20027Response.


        :param floating_fe_ip: The floating_fe_ip of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._floating_fe_ip = floating_fe_ip

    @property
    def floating_fe_ipv6(self):
        """Gets the floating_fe_ipv6 of this InlineResponse20027Response.  # noqa: E501


        :return: The floating_fe_ipv6 of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._floating_fe_ipv6

    @floating_fe_ipv6.setter
    def floating_fe_ipv6(self, floating_fe_ipv6):
        """Sets the floating_fe_ipv6 of this InlineResponse20027Response.


        :param floating_fe_ipv6: The floating_fe_ipv6 of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._floating_fe_ipv6 = floating_fe_ipv6

    @property
    def floating_be_ip(self):
        """Gets the floating_be_ip of this InlineResponse20027Response.  # noqa: E501


        :return: The floating_be_ip of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._floating_be_ip

    @floating_be_ip.setter
    def floating_be_ip(self, floating_be_ip):
        """Sets the floating_be_ip of this InlineResponse20027Response.


        :param floating_be_ip: The floating_be_ip of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._floating_be_ip = floating_be_ip

    @property
    def publicip(self):
        """Gets the publicip of this InlineResponse20027Response.  # noqa: E501


        :return: The publicip of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._publicip

    @publicip.setter
    def publicip(self, publicip):
        """Sets the publicip of this InlineResponse20027Response.


        :param publicip: The publicip of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._publicip = publicip

    @property
    def auto_scale(self):
        """Gets the auto_scale of this InlineResponse20027Response.  # noqa: E501


        :return: The auto_scale of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._auto_scale

    @auto_scale.setter
    def auto_scale(self, auto_scale):
        """Sets the auto_scale of this InlineResponse20027Response.


        :param auto_scale: The auto_scale of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._auto_scale = auto_scale

    @property
    def billing_unit(self):
        """Gets the billing_unit of this InlineResponse20027Response.  # noqa: E501


        :return: The billing_unit of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._billing_unit

    @billing_unit.setter
    def billing_unit(self, billing_unit):
        """Sets the billing_unit of this InlineResponse20027Response.


        :param billing_unit: The billing_unit of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._billing_unit = billing_unit

    @property
    def upload_rate_per_gb(self):
        """Gets the upload_rate_per_gb of this InlineResponse20027Response.  # noqa: E501


        :return: The upload_rate_per_gb of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._upload_rate_per_gb

    @upload_rate_per_gb.setter
    def upload_rate_per_gb(self, upload_rate_per_gb):
        """Sets the upload_rate_per_gb of this InlineResponse20027Response.


        :param upload_rate_per_gb: The upload_rate_per_gb of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._upload_rate_per_gb = upload_rate_per_gb

    @property
    def download_rate_per_gb(self):
        """Gets the download_rate_per_gb of this InlineResponse20027Response.  # noqa: E501


        :return: The download_rate_per_gb of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._download_rate_per_gb

    @download_rate_per_gb.setter
    def download_rate_per_gb(self, download_rate_per_gb):
        """Sets the download_rate_per_gb of this InlineResponse20027Response.


        :param download_rate_per_gb: The download_rate_per_gb of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._download_rate_per_gb = download_rate_per_gb

    @property
    def api_ip(self):
        """Gets the api_ip of this InlineResponse20027Response.  # noqa: E501


        :return: The api_ip of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._api_ip

    @api_ip.setter
    def api_ip(self, api_ip):
        """Sets the api_ip of this InlineResponse20027Response.


        :param api_ip: The api_ip of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._api_ip = api_ip

    @property
    def api_hostname(self):
        """Gets the api_hostname of this InlineResponse20027Response.  # noqa: E501


        :return: The api_hostname of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._api_hostname

    @api_hostname.setter
    def api_hostname(self, api_hostname):
        """Sets the api_hostname of this InlineResponse20027Response.


        :param api_hostname: The api_hostname of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._api_hostname = api_hostname

    @property
    def zswift_ratelimit_enabled(self):
        """Gets the zswift_ratelimit_enabled of this InlineResponse20027Response.  # noqa: E501


        :return: The zswift_ratelimit_enabled of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._zswift_ratelimit_enabled

    @zswift_ratelimit_enabled.setter
    def zswift_ratelimit_enabled(self, zswift_ratelimit_enabled):
        """Sets the zswift_ratelimit_enabled of this InlineResponse20027Response.


        :param zswift_ratelimit_enabled: The zswift_ratelimit_enabled of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._zswift_ratelimit_enabled = zswift_ratelimit_enabled

    @property
    def zswift_ratelimit(self):
        """Gets the zswift_ratelimit of this InlineResponse20027Response.  # noqa: E501


        :return: The zswift_ratelimit of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._zswift_ratelimit

    @zswift_ratelimit.setter
    def zswift_ratelimit(self, zswift_ratelimit):
        """Sets the zswift_ratelimit of this InlineResponse20027Response.


        :param zswift_ratelimit: The zswift_ratelimit of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._zswift_ratelimit = zswift_ratelimit

    @property
    def vhs_state(self):
        """Gets the vhs_state of this InlineResponse20027Response.  # noqa: E501


        :return: The vhs_state of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._vhs_state

    @vhs_state.setter
    def vhs_state(self, vhs_state):
        """Sets the vhs_state of this InlineResponse20027Response.


        :param vhs_state: The vhs_state of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._vhs_state = vhs_state

    @property
    def admin_access_enabled(self):
        """Gets the admin_access_enabled of this InlineResponse20027Response.  # noqa: E501


        :return: The admin_access_enabled of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._admin_access_enabled

    @admin_access_enabled.setter
    def admin_access_enabled(self, admin_access_enabled):
        """Sets the admin_access_enabled of this InlineResponse20027Response.


        :param admin_access_enabled: The admin_access_enabled of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._admin_access_enabled = admin_access_enabled

    @property
    def allow_tenant_name_in_url(self):
        """Gets the allow_tenant_name_in_url of this InlineResponse20027Response.  # noqa: E501


        :return: The allow_tenant_name_in_url of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._allow_tenant_name_in_url

    @allow_tenant_name_in_url.setter
    def allow_tenant_name_in_url(self, allow_tenant_name_in_url):
        """Sets the allow_tenant_name_in_url of this InlineResponse20027Response.


        :param allow_tenant_name_in_url: The allow_tenant_name_in_url of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._allow_tenant_name_in_url = allow_tenant_name_in_url

    @property
    def token_expiry(self):
        """Gets the token_expiry of this InlineResponse20027Response.  # noqa: E501


        :return: The token_expiry of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._token_expiry

    @token_expiry.setter
    def token_expiry(self, token_expiry):
        """Sets the token_expiry of this InlineResponse20027Response.


        :param token_expiry: The token_expiry of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._token_expiry = token_expiry

    @property
    def policy_action(self):
        """Gets the policy_action of this InlineResponse20027Response.  # noqa: E501


        :return: The policy_action of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._policy_action

    @policy_action.setter
    def policy_action(self, policy_action):
        """Sets the policy_action of this InlineResponse20027Response.


        :param policy_action: The policy_action of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._policy_action = policy_action

    @property
    def zios_upgrade(self):
        """Gets the zios_upgrade of this InlineResponse20027Response.  # noqa: E501


        :return: The zios_upgrade of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._zios_upgrade

    @zios_upgrade.setter
    def zios_upgrade(self, zios_upgrade):
        """Sets the zios_upgrade of this InlineResponse20027Response.


        :param zios_upgrade: The zios_upgrade of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._zios_upgrade = zios_upgrade

    @property
    def ssl_termination(self):
        """Gets the ssl_termination of this InlineResponse20027Response.  # noqa: E501


        :return: The ssl_termination of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._ssl_termination

    @ssl_termination.setter
    def ssl_termination(self, ssl_termination):
        """Sets the ssl_termination of this InlineResponse20027Response.


        :param ssl_termination: The ssl_termination of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._ssl_termination = ssl_termination

    @property
    def created_at(self):
        """Gets the created_at of this InlineResponse20027Response.  # noqa: E501


        :return: The created_at of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InlineResponse20027Response.


        :param created_at: The created_at of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this InlineResponse20027Response.  # noqa: E501


        :return: The modified_at of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this InlineResponse20027Response.


        :param modified_at: The modified_at of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    @property
    def expire_password(self):
        """Gets the expire_password of this InlineResponse20027Response.  # noqa: E501


        :return: The expire_password of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._expire_password

    @expire_password.setter
    def expire_password(self, expire_password):
        """Sets the expire_password of this InlineResponse20027Response.


        :param expire_password: The expire_password of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._expire_password = expire_password

    @property
    def expire_password_after(self):
        """Gets the expire_password_after of this InlineResponse20027Response.  # noqa: E501


        :return: The expire_password_after of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._expire_password_after

    @expire_password_after.setter
    def expire_password_after(self, expire_password_after):
        """Sets the expire_password_after of this InlineResponse20027Response.


        :param expire_password_after: The expire_password_after of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._expire_password_after = expire_password_after

    @property
    def password_history(self):
        """Gets the password_history of this InlineResponse20027Response.  # noqa: E501


        :return: The password_history of this InlineResponse20027Response.  # noqa: E501
        :rtype: str
        """
        return self._password_history

    @password_history.setter
    def password_history(self, password_history):
        """Sets the password_history of this InlineResponse20027Response.


        :param password_history: The password_history of this InlineResponse20027Response.  # noqa: E501
        :type: str
        """

        self._password_history = password_history

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20027Response, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20027Response):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20027Response):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from CommandCenter.api_client import ApiClient


class RemoteAuthenticationsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_remote_authentication_server(self, create_remote_authentication_server, **kwargs):  # noqa: E501
        """create_remote_authentication_server  # noqa: E501

        Create remote authentication server.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_remote_authentication_server(create_remote_authentication_server, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateRemoteAuthenticationServer create_remote_authentication_server: (required)
        :return: InlineResponse20046
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_remote_authentication_server_with_http_info(create_remote_authentication_server, **kwargs)  # noqa: E501
        else:
            (data) = self.create_remote_authentication_server_with_http_info(create_remote_authentication_server, **kwargs)  # noqa: E501
            return data

    def create_remote_authentication_server_with_http_info(self, create_remote_authentication_server, **kwargs):  # noqa: E501
        """create_remote_authentication_server  # noqa: E501

        Create remote authentication server.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_remote_authentication_server_with_http_info(create_remote_authentication_server, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateRemoteAuthenticationServer create_remote_authentication_server: (required)
        :return: InlineResponse20046
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['create_remote_authentication_server']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_remote_authentication_server" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'create_remote_authentication_server' is set
        if self.api_client.client_side_validation and ('create_remote_authentication_server' not in params or
                                                       params['create_remote_authentication_server'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `create_remote_authentication_server` when calling `create_remote_authentication_server`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_remote_authentication_server' in params:
            body_params = params['create_remote_authentication_server']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/remote_authentications.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20046',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_remote_authentication_server(self, auth_server_id, **kwargs):  # noqa: E501
        """delete_remote_authentication_server  # noqa: E501

        Deletes remote authentication server.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_remote_authentication_server(auth_server_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str auth_server_id: (required)
        :return: Default
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_remote_authentication_server_with_http_info(auth_server_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_remote_authentication_server_with_http_info(auth_server_id, **kwargs)  # noqa: E501
            return data

    def delete_remote_authentication_server_with_http_info(self, auth_server_id, **kwargs):  # noqa: E501
        """delete_remote_authentication_server  # noqa: E501

        Deletes remote authentication server.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_remote_authentication_server_with_http_info(auth_server_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str auth_server_id: (required)
        :return: Default
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['auth_server_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_remote_authentication_server" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'auth_server_id' is set
        if self.api_client.client_side_validation and ('auth_server_id' not in params or
                                                       params['auth_server_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `auth_server_id` when calling `delete_remote_authentication_server`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'auth_server_id' in params:
            path_params['auth_server_id'] = params['auth_server_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/remote_authentications/{auth_server_id}.json', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Default',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_remote_authentication_server(self, auth_server_id, **kwargs):  # noqa: E501
        """get_remote_authentication_server  # noqa: E501

        Return a single remote authentication server.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_remote_authentication_server(auth_server_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str auth_server_id: (required)
        :return: InlineResponse20047
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_remote_authentication_server_with_http_info(auth_server_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_remote_authentication_server_with_http_info(auth_server_id, **kwargs)  # noqa: E501
            return data

    def get_remote_authentication_server_with_http_info(self, auth_server_id, **kwargs):  # noqa: E501
        """get_remote_authentication_server  # noqa: E501

        Return a single remote authentication server.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_remote_authentication_server_with_http_info(auth_server_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str auth_server_id: (required)
        :return: InlineResponse20047
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['auth_server_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_remote_authentication_server" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'auth_server_id' is set
        if self.api_client.client_side_validation and ('auth_server_id' not in params or
                                                       params['auth_server_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `auth_server_id` when calling `get_remote_authentication_server`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'auth_server_id' in params:
            path_params['auth_server_id'] = params['auth_server_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/remote_authentications/{auth_server_id}.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20047',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_user_list_of_remote_directory(self, auth_server_id, username, password, **kwargs):  # noqa: E501
        """get_user_list_of_remote_directory  # noqa: E501

        Get user list of a remote directory.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_list_of_remote_directory(auth_server_id, username, password, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str auth_server_id: (required)
        :param str username: remote administrator domain and username. Zadara doesn't store your username. (required)
        :param str password: remote administrator password. Zadara doesn't store your password. Your credentials are only used to authenticate session with your directory. (required)
        :return: InlineResponse20048
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_user_list_of_remote_directory_with_http_info(auth_server_id, username, password, **kwargs)  # noqa: E501
        else:
            (data) = self.get_user_list_of_remote_directory_with_http_info(auth_server_id, username, password, **kwargs)  # noqa: E501
            return data

    def get_user_list_of_remote_directory_with_http_info(self, auth_server_id, username, password, **kwargs):  # noqa: E501
        """get_user_list_of_remote_directory  # noqa: E501

        Get user list of a remote directory.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_list_of_remote_directory_with_http_info(auth_server_id, username, password, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str auth_server_id: (required)
        :param str username: remote administrator domain and username. Zadara doesn't store your username. (required)
        :param str password: remote administrator password. Zadara doesn't store your password. Your credentials are only used to authenticate session with your directory. (required)
        :return: InlineResponse20048
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['auth_server_id', 'username', 'password']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_user_list_of_remote_directory" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'auth_server_id' is set
        if self.api_client.client_side_validation and ('auth_server_id' not in params or
                                                       params['auth_server_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `auth_server_id` when calling `get_user_list_of_remote_directory`")  # noqa: E501
        # verify the required parameter 'username' is set
        if self.api_client.client_side_validation and ('username' not in params or
                                                       params['username'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `username` when calling `get_user_list_of_remote_directory`")  # noqa: E501
        # verify the required parameter 'password' is set
        if self.api_client.client_side_validation and ('password' not in params or
                                                       params['password'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `password` when calling `get_user_list_of_remote_directory`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'auth_server_id' in params:
            path_params['auth_server_id'] = params['auth_server_id']  # noqa: E501

        query_params = []
        if 'username' in params:
            query_params.append(('username', params['username']))  # noqa: E501
        if 'password' in params:
            query_params.append(('password', params['password']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/remote_authentications/{auth_server_id}/users.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20048',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def import_users_from_remote_directory(self, auth_server_id, import_users_from_remote_directory, **kwargs):  # noqa: E501
        """import_users_from_remote_directory  # noqa: E501

        Imports users from remote directory.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.import_users_from_remote_directory(auth_server_id, import_users_from_remote_directory, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str auth_server_id: (required)
        :param ImportUsersFromRemoteDirectory import_users_from_remote_directory: (required)
        :return: InlineResponse20049
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.import_users_from_remote_directory_with_http_info(auth_server_id, import_users_from_remote_directory, **kwargs)  # noqa: E501
        else:
            (data) = self.import_users_from_remote_directory_with_http_info(auth_server_id, import_users_from_remote_directory, **kwargs)  # noqa: E501
            return data

    def import_users_from_remote_directory_with_http_info(self, auth_server_id, import_users_from_remote_directory, **kwargs):  # noqa: E501
        """import_users_from_remote_directory  # noqa: E501

        Imports users from remote directory.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.import_users_from_remote_directory_with_http_info(auth_server_id, import_users_from_remote_directory, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str auth_server_id: (required)
        :param ImportUsersFromRemoteDirectory import_users_from_remote_directory: (required)
        :return: InlineResponse20049
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['auth_server_id', 'import_users_from_remote_directory']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method import_users_from_remote_directory" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'auth_server_id' is set
        if self.api_client.client_side_validation and ('auth_server_id' not in params or
                                                       params['auth_server_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `auth_server_id` when calling `import_users_from_remote_directory`")  # noqa: E501
        # verify the required parameter 'import_users_from_remote_directory' is set
        if self.api_client.client_side_validation and ('import_users_from_remote_directory' not in params or
                                                       params['import_users_from_remote_directory'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `import_users_from_remote_directory` when calling `import_users_from_remote_directory`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'auth_server_id' in params:
            path_params['auth_server_id'] = params['auth_server_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'import_users_from_remote_directory' in params:
            body_params = params['import_users_from_remote_directory']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/remote_authentications/{auth_server_id}/users/import.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20049',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_remote_authentication_servers(self, **kwargs):  # noqa: E501
        """list_remote_authentication_servers  # noqa: E501

        Return remote authentication servers list.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_remote_authentication_servers(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse20045
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_remote_authentication_servers_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.list_remote_authentication_servers_with_http_info(**kwargs)  # noqa: E501
            return data

    def list_remote_authentication_servers_with_http_info(self, **kwargs):  # noqa: E501
        """list_remote_authentication_servers  # noqa: E501

        Return remote authentication servers list.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_remote_authentication_servers_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse20045
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_remote_authentication_servers" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/remote_authentications.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20045',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse20025Performances(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'iops': 'InlineResponse20025Iops',
        'iotime': 'InlineResponse20025Iotime',
        'bandwidth': 'InlineResponse20025Iotime',
        'queue_length': 'InlineResponse20025Iops',
        '_datetime': 'str',
        'label': 'str'
    }

    attribute_map = {
        'iops': 'iops',
        'iotime': 'iotime',
        'bandwidth': 'bandwidth',
        'queue_length': 'queue_length',
        '_datetime': 'datetime',
        'label': 'label'
    }

    def __init__(self, iops=None, iotime=None, bandwidth=None, queue_length=None, _datetime=None, label=None, _configuration=None):  # noqa: E501
        """InlineResponse20025Performances - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._iops = None
        self._iotime = None
        self._bandwidth = None
        self._queue_length = None
        self.__datetime = None
        self._label = None
        self.discriminator = None

        if iops is not None:
            self.iops = iops
        if iotime is not None:
            self.iotime = iotime
        if bandwidth is not None:
            self.bandwidth = bandwidth
        if queue_length is not None:
            self.queue_length = queue_length
        if _datetime is not None:
            self._datetime = _datetime
        if label is not None:
            self.label = label

    @property
    def iops(self):
        """Gets the iops of this InlineResponse20025Performances.  # noqa: E501


        :return: The iops of this InlineResponse20025Performances.  # noqa: E501
        :rtype: InlineResponse20025Iops
        """
        return self._iops

    @iops.setter
    def iops(self, iops):
        """Sets the iops of this InlineResponse20025Performances.


        :param iops: The iops of this InlineResponse20025Performances.  # noqa: E501
        :type: InlineResponse20025Iops
        """

        self._iops = iops

    @property
    def iotime(self):
        """Gets the iotime of this InlineResponse20025Performances.  # noqa: E501


        :return: The iotime of this InlineResponse20025Performances.  # noqa: E501
        :rtype: InlineResponse20025Iotime
        """
        return self._iotime

    @iotime.setter
    def iotime(self, iotime):
        """Sets the iotime of this InlineResponse20025Performances.


        :param iotime: The iotime of this InlineResponse20025Performances.  # noqa: E501
        :type: InlineResponse20025Iotime
        """

        self._iotime = iotime

    @property
    def bandwidth(self):
        """Gets the bandwidth of this InlineResponse20025Performances.  # noqa: E501


        :return: The bandwidth of this InlineResponse20025Performances.  # noqa: E501
        :rtype: InlineResponse20025Iotime
        """
        return self._bandwidth

    @bandwidth.setter
    def bandwidth(self, bandwidth):
        """Sets the bandwidth of this InlineResponse20025Performances.


        :param bandwidth: The bandwidth of this InlineResponse20025Performances.  # noqa: E501
        :type: InlineResponse20025Iotime
        """

        self._bandwidth = bandwidth

    @property
    def queue_length(self):
        """Gets the queue_length of this InlineResponse20025Performances.  # noqa: E501


        :return: The queue_length of this InlineResponse20025Performances.  # noqa: E501
        :rtype: InlineResponse20025Iops
        """
        return self._queue_length

    @queue_length.setter
    def queue_length(self, queue_length):
        """Sets the queue_length of this InlineResponse20025Performances.


        :param queue_length: The queue_length of this InlineResponse20025Performances.  # noqa: E501
        :type: InlineResponse20025Iops
        """

        self._queue_length = queue_length

    @property
    def _datetime(self):
        """Gets the _datetime of this InlineResponse20025Performances.  # noqa: E501


        :return: The _datetime of this InlineResponse20025Performances.  # noqa: E501
        :rtype: str
        """
        return self.__datetime

    @_datetime.setter
    def _datetime(self, _datetime):
        """Sets the _datetime of this InlineResponse20025Performances.


        :param _datetime: The _datetime of this InlineResponse20025Performances.  # noqa: E501
        :type: str
        """

        self.__datetime = _datetime

    @property
    def label(self):
        """Gets the label of this InlineResponse20025Performances.  # noqa: E501


        :return: The label of this InlineResponse20025Performances.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this InlineResponse20025Performances.


        :param label: The label of this InlineResponse20025Performances.  # noqa: E501
        :type: str
        """

        self._label = label

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20025Performances, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20025Performances):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20025Performances):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import CommandCenter
from CommandCenter.api.users_api import UsersApi  # noqa: E501
from CommandCenter.rest import ApiException


class TestUsersApi(unittest.TestCase):
    """UsersApi unit test stubs"""

    def setUp(self):
        self.api = CommandCenter.api.users_api.UsersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_user(self):
        """Test case for create_user

        """
        pass

    def test_delete_user(self):
        """Test case for delete_user

        """
        pass

    def test_get_all_users(self):
        """Test case for get_all_users

        """
        pass

    def test_get_user(self):
        """Test case for get_user

        """
        pass

    def test_get_user_api_key(self):
        """Test case for get_user_api_key

        """
        pass

    def test_regenerate_user_api_token(self):
        """Test case for regenerate_user_api_token

        """
        pass

    def test_update_user(self):
        """Test case for update_user

        """
        pass


if __name__ == '__main__':
    unittest.main()
